#[non_exhaustive]pub enum ObjectClass {
vehicleSubClass(TrafficParticipantType),
vruSubClass(VruProfileAndSubprofile),
groupSubClass(VruClusterInformation),
otherSubClass(OtherSubClass),
}Expand description
- This DF indicates both the class and associated subclass that best describes an object.
- The following options are available:
- @field vehicleSubClass: the object is a road vehicle and the specific subclass is specified.
- @field vruSubClass: the object is a VRU and the specific subclass is specified.
- @field groupSubClass: the object is a VRU group or cluster and the cluster information is specified.
- @field otherSubClass: the object is of a different type than the above and the specific subclass is specified.
- @category: Sensing information
- @revision: Created in V2.1.1
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
vehicleSubClass(TrafficParticipantType)
vruSubClass(VruProfileAndSubprofile)
groupSubClass(VruClusterInformation)
otherSubClass(OtherSubClass)