pub struct BasicLaneConfiguration(pub SequenceOf<BasicLaneInformation>);Expand description
- This DF provides information about the configuration of a road section in terms of lanes using a list of @ref LanePositionAndType .
- @category: Road topology information
- @revision: Created in V2.2.1
Tuple Fields
0: SequenceOf<BasicLaneInformation>Trait Implementations
Sourceimpl AsnType for BasicLaneConfiguration
impl AsnType for BasicLaneConfiguration
Sourceconst TAG: Tag = { <SequenceOf<BasicLaneInformation> as rasn::AsnType>::TAG }
const TAG: Tag = { <SequenceOf<BasicLaneInformation> as rasn::AsnType>::TAG }
The associated tag for the type. Read more
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst CONSTRAINTS: Constraints
const CONSTRAINTS: Constraints
The set of constraints for values of the given type.
Sourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Clone for BasicLaneConfiguration
impl Clone for BasicLaneConfiguration
Sourcefn clone(&self) -> BasicLaneConfiguration
fn clone(&self) -> BasicLaneConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BasicLaneConfiguration
impl Debug for BasicLaneConfiguration
Sourceimpl Decode for BasicLaneConfiguration
impl Decode for BasicLaneConfiguration
Sourcefn decode_with_tag_and_constraints<D: Decoder>(
decoder: &mut D,
tag: Tag,
constraints: Constraints,
) -> Result<Self, D::Error>
fn decode_with_tag_and_constraints<D: Decoder>( decoder: &mut D, tag: Tag, constraints: Constraints, ) -> Result<Self, D::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl Encode for BasicLaneConfiguration
impl Encode for BasicLaneConfiguration
Sourcefn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>(
&self,
encoder: &mut EN,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), EN::Error>
fn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>( &self, encoder: &mut EN, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), EN::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreSourceimpl Hash for BasicLaneConfiguration
impl Hash for BasicLaneConfiguration
Sourceimpl PartialEq for BasicLaneConfiguration
impl PartialEq for BasicLaneConfiguration
impl Eq for BasicLaneConfiguration
impl StructuralPartialEq for BasicLaneConfiguration