pub struct CartesianAngularAccelerationComponent {
pub value: CartesianAngularAccelerationComponentValue,
pub confidence: AngularAccelerationConfidence,
}Expand description
- This DF represents a general Data Frame to describe an angular acceleration component along with a confidence value in a cartesian coordinate system.
- It shall include the following components:
- @field value: The angular acceleration component value.
- @field confidence: The confidence value associated to the provided value.
- @category: Kinematic information
- @revision: Created in V2.1.1
Fields
value: CartesianAngularAccelerationComponentValueconfidence: AngularAccelerationConfidenceImplementations
Sourceimpl CartesianAngularAccelerationComponent
impl CartesianAngularAccelerationComponent
pub fn new( value: CartesianAngularAccelerationComponentValue, confidence: AngularAccelerationConfidence, ) -> Self