pub struct DeltaLatitude(pub i32);Expand description
- This DE represents an offset latitude with regards to a defined latitude value.
- It may be used to describe a geographical point with regards to a specific reference geographical position.
- The value shall be set to:
-
n(n >= -131 071andn < 0) for offset n x 10^-7 degree towards the south from the reference position,
-
0for no latitudinal offset,
-
n(n > 0andn < 131 072) for offset n x 10^-7 degree towards the north from the reference position,
-
131 072when the information is unavailable.
- @unit: 10^-7 degree
- @category: GeoReference information
- @revision: editorial update in V2.1.1
Tuple Fields
0: i32Trait Implementations
Sourceimpl AsnType for DeltaLatitude
impl AsnType for DeltaLatitude
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst CONSTRAINTS: Constraints
const CONSTRAINTS: Constraints
The set of constraints for values of the given type.
Sourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Clone for DeltaLatitude
impl Clone for DeltaLatitude
Sourcefn clone(&self) -> DeltaLatitude
fn clone(&self) -> DeltaLatitude
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeltaLatitude
impl Debug for DeltaLatitude
Sourceimpl Decode for DeltaLatitude
impl Decode for DeltaLatitude
Sourcefn decode_with_tag_and_constraints<D: Decoder>(
decoder: &mut D,
tag: Tag,
constraints: Constraints,
) -> Result<Self, D::Error>
fn decode_with_tag_and_constraints<D: Decoder>( decoder: &mut D, tag: Tag, constraints: Constraints, ) -> Result<Self, D::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl Encode for DeltaLatitude
impl Encode for DeltaLatitude
Sourcefn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>(
&self,
encoder: &mut EN,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), EN::Error>
fn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>( &self, encoder: &mut EN, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), EN::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreSourceimpl Hash for DeltaLatitude
impl Hash for DeltaLatitude
Sourceimpl PartialEq for DeltaLatitude
impl PartialEq for DeltaLatitude
impl Eq for DeltaLatitude
impl StructuralPartialEq for DeltaLatitude