Heading

pub struct Heading {
    pub heading_value: HeadingValue,
    pub heading_confidence: HeadingConfidence,
}
  • This DF represents the Heading in a WGS84 co-ordinates system.
  • The specific WGS84 coordinate system is specified by the corresponding standards applying this DE.
  • It shall include the following components:
  • @field headingValue: the heading value.
  • @field headingConfidence: the confidence value of the heading value with a predefined confidence level.
  • @note: this DF is kept for backwards compatibility reasons only. It is recommended to use the @ref Wgs84Angle instead.
  • @category: Kinematic Information
  • @revision: Description revised in V2.1.1

Fields

heading_value: HeadingValueheading_confidence: HeadingConfidence

Implementations

Source

impl Heading

pub fn new( heading_value: HeadingValue, heading_confidence: HeadingConfidence, ) -> Self

Examples found in repository?
examples/bench_congestion.rs (line 410)
408fn make_cam(station_id: u32) -> Cam {
409    let hf = BasicVehicleContainerHighFrequency::new(
410        Heading::new(HeadingValue(900), HeadingConfidence(127)),
411        Speed::new(SpeedValue(0), SpeedConfidence(127)),
412        DriveDirection::unavailable,
413        VehicleLength::new(
414            VehicleLengthValue(1023),
415            VehicleLengthConfidenceIndication::unavailable,
416        ),
417        VehicleWidth(62),
418        AccelerationComponent::new(AccelerationValue(161), AccelerationConfidence(102)),
419        Curvature::new(CurvatureValue(1023), CurvatureConfidence::unavailable),
420        CurvatureCalculationMode::unavailable,
421        YawRate::new(YawRateValue(32767), YawRateConfidence::unavailable),
422        None,
423        None,
424        None,
425        None,
426        None,
427        None,
428        None,
429    );
430    Cam::new(
431        cam_header(station_id),
432        CamPayload::new(
433            cam_gdt(),
434            CamParameters::new(
435                BasicContainer::new(
436                    TrafficParticipantType(5),
437                    ReferencePositionWithConfidence::new(
438                        Latitude(415_520_000),
439                        Longitude(21_340_000),
440                        PositionConfidenceEllipse::new(
441                            SemiAxisLength(4095),
442                            SemiAxisLength(4095),
443                            Wgs84AngleValue(3601),
444                        ),
445                        Altitude::new(AltitudeValue(12000), AltitudeConfidence::unavailable),
446                    ),
447                ),
448                HighFrequencyContainer::basicVehicleContainerHighFrequency(hf),
449                None,
450                None,
451                None,
452            ),
453        ),
454    )
455}
More examples
Hide additional examples
examples/bench_cam_tx.rs (line 150)
148fn make_cam(station_id: u32) -> Cam {
149    let hf = BasicVehicleContainerHighFrequency::new(
150        Heading::new(HeadingValue(900), HeadingConfidence(127)),
151        Speed::new(SpeedValue(0), SpeedConfidence(127)),
152        DriveDirection::unavailable,
153        VehicleLength::new(
154            VehicleLengthValue(1023),
155            VehicleLengthConfidenceIndication::unavailable,
156        ),
157        VehicleWidth(62),
158        AccelerationComponent::new(AccelerationValue(161), AccelerationConfidence(102)),
159        Curvature::new(CurvatureValue(1023), CurvatureConfidence::unavailable),
160        CurvatureCalculationMode::unavailable,
161        YawRate::new(YawRateValue(32767), YawRateConfidence::unavailable),
162        None,
163        None,
164        None,
165        None,
166        None,
167        None,
168        None,
169    );
170    Cam::new(
171        cam_header(station_id),
172        CamPayload::new(
173            generation_delta_time_now(),
174            CamParameters::new(
175                BasicContainer::new(
176                    TrafficParticipantType(5),
177                    ReferencePositionWithConfidence::new(
178                        Latitude(415_520_000),
179                        Longitude(21_340_000),
180                        PositionConfidenceEllipse::new(
181                            SemiAxisLength(4095),
182                            SemiAxisLength(4095),
183                            Wgs84AngleValue(3601),
184                        ),
185                        Altitude::new(AltitudeValue(12000), AltitudeConfidence::unavailable),
186                    ),
187                ),
188                HighFrequencyContainer::basicVehicleContainerHighFrequency(hf),
189                None,
190                None,
191                None,
192            ),
193        ),
194    )
195}