pub struct ImpassabilitySubCauseCode(pub u8);Expand description
- This DE represents the value of the sub cause codes of the @ref CauseCode
impassability - The value shall be set to:
-
- 0
unavailable- in case further detailed information about the unmanaged road blockage is unavailable,
- 0
-
- 1
flooding- in case the road is affected by flooding,
- 1
-
- 2
dangerOfAvalanches- in case the road is at risk of being affected or blocked by avalanches,
- 2
-
- 3
blastingOfAvalanches- in case there is an active blasting of avalanches on or near the road,
- 3
-
- 4
landslips- in case the road is affected by landslips,
- 4
-
- 5
chemicalSpillage- in case the road is affected by chemical spillage,
- 5
-
- 6
winterClosure- in case the road is impassable due to a winter closure.
- 6
-
- 7
sinkhole- in case the road is impassable due to large holes in the road surface.
- 7
-
- 8
earthquakeDamage- in case the road is obstructed or partially obstructed because of damage caused by an earthquake.
- 8
-
- 9
fallenTrees- in case the road is obstructed or partially obstructed by one or more fallen trees.
- 9
-
- 10
rockfalls- in case the road is obstructed or partially obstructed due to fallen rocks.
- 10
-
- 11
sewerOverflow- in case the road is obstructed or partially obstructed by overflows from one or more sewers.
- 11
-
- 12
stormDamage- in case the road is obstructed or partially obstructed by debris caused by strong winds.
- 12
-
- 13
subsidence- in case the road surface has sunken or collapsed in places.
- 13
-
- 14
burstPipe- in case the road surface has sunken or collapsed in places due to burst pipes.
- 14
-
- 15
burstWaterMain- in case the road is obstructed due to local flooding and/or subsidence.
- 15
-
- 16
fallenPowerCables- in case the road is obstructed or partly obstructed by one or more fallen power cables.
- 16
-
- 17
snowDrifts- in case the road is obstructed or partially obstructed by snow drifting in progress or patches of deep snow due to earlier drifting.
- 17
-
- 15-255 - are reserved for future usage.
- @category: Traffic information
- @revision: Created in V2.2.1
Tuple Fields
0: u8Trait Implementations
Sourceimpl AsnType for ImpassabilitySubCauseCode
impl AsnType for ImpassabilitySubCauseCode
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst CONSTRAINTS: Constraints
const CONSTRAINTS: Constraints
The set of constraints for values of the given type.
Sourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Clone for ImpassabilitySubCauseCode
impl Clone for ImpassabilitySubCauseCode
Sourcefn clone(&self) -> ImpassabilitySubCauseCode
fn clone(&self) -> ImpassabilitySubCauseCode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImpassabilitySubCauseCode
impl Debug for ImpassabilitySubCauseCode
Sourceimpl Decode for ImpassabilitySubCauseCode
impl Decode for ImpassabilitySubCauseCode
Sourcefn decode_with_tag_and_constraints<D: Decoder>(
decoder: &mut D,
tag: Tag,
constraints: Constraints,
) -> Result<Self, D::Error>
fn decode_with_tag_and_constraints<D: Decoder>( decoder: &mut D, tag: Tag, constraints: Constraints, ) -> Result<Self, D::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl Encode for ImpassabilitySubCauseCode
impl Encode for ImpassabilitySubCauseCode
Sourcefn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>(
&self,
encoder: &mut EN,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), EN::Error>
fn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>( &self, encoder: &mut EN, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), EN::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreSourceimpl Hash for ImpassabilitySubCauseCode
impl Hash for ImpassabilitySubCauseCode
impl Eq for ImpassabilitySubCauseCode
impl StructuralPartialEq for ImpassabilitySubCauseCode