#[non_exhaustive]pub struct TrajectoryInterceptionIndication {
pub subject_station: Option<StationId>,
pub trajectory_interception_probability: TrajectoryInterceptionProbability,
pub trajectory_interception_confidence: Option<TrajectoryInterceptionConfidence>,
}Expand description
- This DF provides the trajectory interception indication of ego-VRU ITS-S with another ITS-Ss.
- It shall include the following components:
- @field subjectStation: indicates the subject station.
- @field trajectoryInterceptionProbability: indicates the propbability of the interception of the subject station trajectory
- with the trajectory of the station indicated in the component subjectStation.
- @field trajectoryInterceptionConfidence: indicates the confidence of interception of the subject station trajectory
- with the trajectory of the station indicated in the component subjectStation.
- @category: Vehicle information
- @revision: Created in V2.1.1
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subject_station: Option<StationId>trajectory_interception_probability: TrajectoryInterceptionProbabilitytrajectory_interception_confidence: Option<TrajectoryInterceptionConfidence>Implementations
Sourceimpl TrajectoryInterceptionIndication
impl TrajectoryInterceptionIndication
pub fn new( subject_station: Option<StationId>, trajectory_interception_probability: TrajectoryInterceptionProbability, trajectory_interception_confidence: Option<TrajectoryInterceptionConfidence>, ) -> Self