#[non_exhaustive]pub struct BasicContainer {
pub station_type: TrafficParticipantType,
pub reference_position: ReferencePositionWithConfidence,
}Expand description
- This DE represents a general container for usage in various types of messages.
- It shall include the following components:
- @field stationType: the type of technical context in which the ITS-S that has generated the message is integrated in.
- @field referencePosition: the reference position of the station that has generated the message that contains the basic container.
- @category: Basic information
- @revision: Created in V2.1.1
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.station_type: TrafficParticipantTypereference_position: ReferencePositionWithConfidenceImplementations
Sourceimpl BasicContainer
impl BasicContainer
pub fn new( station_type: TrafficParticipantType, reference_position: ReferencePositionWithConfidence, ) -> Self