MapPosition

#[non_exhaustive]
pub struct MapPosition { pub map_reference: Option<MapReference>, pub lane_id: Option<Identifier1B>, pub connection_id: Option<Identifier1B>, pub longitudinal_lane_position: Option<LongitudinalLanePosition>, }
  • This DF indicates a position on a topology description transmitted in a MAPEM according to ETSI TS 103 301 [15].
  • It shall include the following components:
  • @field mapReference: optionally identifies the MAPEM containing the topology information.
  • It is absent if the MAPEM topology is known from the context.
  • @field laneId: optionally identifies the lane in the road segment or intersection topology on which the position is located.
  • @field connectionId: optionally identifies the connection inside the conflict area of an intersection, i.e. it identifies a trajectory for travelling through the
  • conflict area of an intersection which connects e.g an ingress with an egress lane.
  • @field longitudinalLanePosition: optionally indicates the longitudinal offset of the map-matched position of the object along the lane or connection measured from the start of the lane/connection, along the lane.
  • @category: Road topology information
  • @revision: Created in V2.1.1, definition of longitudinalLanePosition amended in V2.2.1

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
map_reference: Option<MapReference>lane_id: Option<Identifier1B>connection_id: Option<Identifier1B>longitudinal_lane_position: Option<LongitudinalLanePosition>

Implementations

Source

impl MapPosition

pub fn new( map_reference: Option<MapReference>, lane_id: Option<Identifier1B>, connection_id: Option<Identifier1B>, longitudinal_lane_position: Option<LongitudinalLanePosition>, ) -> Self