pub struct VehicleBreakdownSubCauseCode(pub u8);Expand description
- This DE represents the value of the sub cause codes of the @ref CauseCode
vehicleBreakdown. - The value shall be set to:
-
- 0
unavailable- in case further detailed information on cause of vehicle break down is unavailable,
- 0
-
- 1
lackOfFuel- in case vehicle break down is due to lack of fuel,
- 1
-
- 2
lackOfBatteryPower- in case vehicle break down is caused by lack of battery power,
- 2
-
- 3
engineProblem- in case vehicle break down is caused by an engine problem,
- 3
-
- 4
transmissionProblem- in case vehicle break down is caused by transmission problem,
- 4
-
- 5
engineCoolingProblem- in case vehicle break down is caused by an engine cooling problem,
- 5
-
- 6
brakingSystemProblem- in case vehicle break down is caused by a braking system problem,
- 6
-
- 7
steeringProblem- in case vehicle break down is caused by a steering problem,
- 7
-
- 8
tyrePuncture-deprecated- deprecated since covered bytyrePressureProblem,
- 8
-
- 9
tyrePressureProblem- in case low tyre pressure in detected,
- 9
-
- 10
vehicleOnFire- in case the vehicle is on fire.
- 10
-
- 11-255 - are reserved for future usage.
- @category: Traffic information
- @revision: V1.3.1, value 10 assigned in V2.1.1, value 8 deprecated in V2.4.1
Tuple Fields
0: u8Trait Implementations
Sourceimpl AsnType for VehicleBreakdownSubCauseCode
impl AsnType for VehicleBreakdownSubCauseCode
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst CONSTRAINTS: Constraints
const CONSTRAINTS: Constraints
The set of constraints for values of the given type.
Sourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Clone for VehicleBreakdownSubCauseCode
impl Clone for VehicleBreakdownSubCauseCode
Sourcefn clone(&self) -> VehicleBreakdownSubCauseCode
fn clone(&self) -> VehicleBreakdownSubCauseCode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VehicleBreakdownSubCauseCode
impl Debug for VehicleBreakdownSubCauseCode
Sourceimpl Decode for VehicleBreakdownSubCauseCode
impl Decode for VehicleBreakdownSubCauseCode
Sourcefn decode_with_tag_and_constraints<D: Decoder>(
decoder: &mut D,
tag: Tag,
constraints: Constraints,
) -> Result<Self, D::Error>
fn decode_with_tag_and_constraints<D: Decoder>( decoder: &mut D, tag: Tag, constraints: Constraints, ) -> Result<Self, D::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl Encode for VehicleBreakdownSubCauseCode
impl Encode for VehicleBreakdownSubCauseCode
Sourcefn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>(
&self,
encoder: &mut EN,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), EN::Error>
fn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>( &self, encoder: &mut EN, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), EN::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreSourceimpl Hash for VehicleBreakdownSubCauseCode
impl Hash for VehicleBreakdownSubCauseCode
Sourceimpl PartialEq for VehicleBreakdownSubCauseCode
impl PartialEq for VehicleBreakdownSubCauseCode
Sourcefn eq(&self, other: &VehicleBreakdownSubCauseCode) -> bool
fn eq(&self, other: &VehicleBreakdownSubCauseCode) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for VehicleBreakdownSubCauseCode
impl StructuralPartialEq for VehicleBreakdownSubCauseCode