#[non_exhaustive]pub struct TrailerData {
pub ref_point_id: Identifier1B,
pub hitch_point_offset: StandardLength1B,
pub front_overhang: Option<StandardLength1B>,
pub rear_overhang: Option<StandardLength1B>,
pub trailer_width: Option<VehicleWidth>,
pub hitch_angle: CartesianAngle,
}Expand description
- This DF provides detailed information about an attached trailer.
- It shall include the following components:
- @field refPointId: identifier of the reference point of the trailer.
- @field hitchPointOffset: optional position of the hitch point in negative x-direction (according to ISO 8855) from the
- vehicle Reference Point.
- @field frontOverhang: optional length of the trailer overhang in the positive x direction (according to ISO 8855) from the
- trailer Reference Point indicated by the refPointID. The value defaults to 0 in case the trailer
- is not overhanging to the front with respect to the trailer reference point.
- @field rearOverhang: optional length of the trailer overhang in the negative x direction (according to ISO 8855) from the
- trailer Reference Point indicated by the refPointID.
- @field trailerWidth: optional width of the trailer.
- @field hitchAngle: optional Value and confidence value of the angle between the trailer orientation (corresponding to the x
- direction of the ISO 8855 [21] coordinate system centered on the trailer) and the direction of
- the segment having as end points the reference point of the trailer and the reference point of
- the pulling vehicle, which can be another trailer or a vehicle looking on the horizontal plane
- xy, described in the local Cartesian coordinate system of the trailer. The
- angle is measured with negative values considering the trailer orientation turning clockwise
- starting from the segment direction. The angle value accuracy is provided with the
- confidence level of 95 %.
- @category: Vehicle information
- @revision: Created in V2.1.1
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ref_point_id: Identifier1Bhitch_point_offset: StandardLength1Bfront_overhang: Option<StandardLength1B>rear_overhang: Option<StandardLength1B>trailer_width: Option<VehicleWidth>hitch_angle: CartesianAngleImplementations
Sourceimpl TrailerData
impl TrailerData
pub fn new( ref_point_id: Identifier1B, hitch_point_offset: StandardLength1B, front_overhang: Option<StandardLength1B>, rear_overhang: Option<StandardLength1B>, trailer_width: Option<VehicleWidth>, hitch_angle: CartesianAngle, ) -> Self