pub struct CertificateBase {
pub version: Uint8,
pub r_type: CertificateType,
pub issuer: IssuerIdentifier,
pub to_be_signed: ToBeSignedCertificate,
pub signature: Option<Signature>,
}Expand description
- @brief The fields in this structure have the following meaning:
- @param version: contains the version of the certificate format. In this
- version of the data structures, this field is set to 3.
- @param type: states whether the certificate is implicit or explicit. This
- field is set to explicit for explicit certificates and to implicit for
- implicit certificates. See ExplicitCertificate and ImplicitCertificate for
- more details.
- @param issuer: identifies the issuer of the certificate.
- @param toBeSigned: is the certificate contents. This field is an input to
- the hash when generating or verifying signatures for an explicit
- certificate, or generating or verifying the public key from the
- reconstruction value for an implicit certificate. The details of how this
- field are encoded are given in the description of the
- ToBeSignedCertificate type.
- @param signature: is included in an ExplicitCertificate. It is the
- signature, calculated by the signer identified in the issuer field, over
- the hash of toBeSigned. The hash is calculated as specified in 5.3.1, where:
-
- Data input is the encoding of toBeSigned following the COER.
-
- Signer identifier input depends on the verification type, which in
- turn depends on the choice indicated by issuer. If the choice indicated by
- issuer is self, the verification type is self-signed and the signer
- identifier input is the empty string. If the choice indicated by issuer is
- not self, the verification type is certificate and the signer identifier
- input is the canonicalized COER encoding of the certificate indicated by
- issuer. The canonicalization is carried out as specified in the
- Canonicalization section of this subclause.
- @note Canonicalization: This data structure is subject to canonicalization
- for the relevant operations specified in 6.1.2. The canonicalization
- applies to the ToBeSignedCertificate and to the Signature.
- @note Whole-certificate hash: If the entirety of a certificate is hashed
- to calculate a HashedId3, HashedId8, or HashedId10, the algorithm used for
- this purpose is known as the whole-certificate hash. The method used to
- determine the whole-certificate hash algorithm is specified in 5.3.9.2.
Fields
version: Uint8r_type: CertificateTypeissuer: IssuerIdentifierto_be_signed: ToBeSignedCertificatesignature: Option<Signature>Implementations
Sourceimpl CertificateBase
impl CertificateBase
pub fn new( version: Uint8, r_type: CertificateType, issuer: IssuerIdentifier, to_be_signed: ToBeSignedCertificate, signature: Option<Signature>, ) -> Self