#[non_exhaustive]pub enum AcaEeInterfacePdu {
acaEeCertResponse(AcaEeCertResponse),
}Expand description
- @brief This is the parent structure for all structures exchanged between
- the ACA and the EE. The ACA - EE interface is a logical interface rather
- than a direct communications interface in that there is no direct message
- flow between the ACA and the EE: Messages from the ACA are stored
- by the RA and subsequently forwarded to the EE. The PDUs are identified as
- ACA-EE PDUs even though the RA acts as a forwarder for them because those
- PDUs are created by the ACA and encrypted for the EE, and not modified and
- frequently not read by the RA. An overview of this structure is as follows:
- @param acaEeCertResponse: contains the ACA’s response to
- RaAcaCertRequestSPDU, which is meant for the EE and sent via the RA.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
acaEeCertResponse(AcaEeCertResponse)