#[non_exhaustive]pub struct CauseCode {
pub cause_code: CauseCodeType,
pub sub_cause_code: SubCauseCodeType,
}Expand description
- This DF is a representation of the cause code value of a traffic event.
- It shall include the following components:
- @field causeCode: the main cause of a detected event.
- @field subCauseCode: the subordinate cause of a detected event.
- The semantics of the entire DF are completely defined by the component causeCode. The interpretation of the subCauseCode may
- provide additional information that is not strictly necessary to understand the causeCode itself, and is therefore optional.
- @note: this DF is kept for backwards compatibility reasons only. It is recommended to use the @ref CauseCodeV2 instead.
- @category: Traffic information
- @revision: Editorial update in V2.1.1
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cause_code: CauseCodeTypesub_cause_code: SubCauseCodeTypeImplementations
Sourceimpl CauseCode
impl CauseCode
pub fn new(cause_code: CauseCodeType, sub_cause_code: SubCauseCodeType) -> Self