pub struct Heading {
pub heading_value: HeadingValue,
pub heading_confidence: HeadingConfidence,
}Expand description
- This DF represents the Heading in a WGS84 co-ordinates system.
- The specific WGS84 coordinate system is specified by the corresponding standards applying this DE.
- It shall include the following components:
- @field headingValue: the heading value.
- @field headingConfidence: the confidence value of the heading value with a predefined confidence level.
- @note: this DF is kept for backwards compatibility reasons only. It is recommended to use the @ref Wgs84Angle instead.
- @category: Kinematic Information
- @revision: Description revised in V2.1.1
Fields
heading_value: HeadingValueheading_confidence: HeadingConfidenceImplementations
Sourceimpl Heading
impl Heading
Sourcepub fn new(
heading_value: HeadingValue,
heading_confidence: HeadingConfidence,
) -> Self
pub fn new( heading_value: HeadingValue, heading_confidence: HeadingConfidence, ) -> Self
Examples found in repository?
examples/bench_congestion.rs (line 410)
408fn make_cam(station_id: u32) -> Cam {
409 let hf = BasicVehicleContainerHighFrequency::new(
410 Heading::new(HeadingValue(900), HeadingConfidence(127)),
411 Speed::new(SpeedValue(0), SpeedConfidence(127)),
412 DriveDirection::unavailable,
413 VehicleLength::new(
414 VehicleLengthValue(1023),
415 VehicleLengthConfidenceIndication::unavailable,
416 ),
417 VehicleWidth(62),
418 AccelerationComponent::new(AccelerationValue(161), AccelerationConfidence(102)),
419 Curvature::new(CurvatureValue(1023), CurvatureConfidence::unavailable),
420 CurvatureCalculationMode::unavailable,
421 YawRate::new(YawRateValue(32767), YawRateConfidence::unavailable),
422 None,
423 None,
424 None,
425 None,
426 None,
427 None,
428 None,
429 );
430 Cam::new(
431 cam_header(station_id),
432 CamPayload::new(
433 cam_gdt(),
434 CamParameters::new(
435 BasicContainer::new(
436 TrafficParticipantType(5),
437 ReferencePositionWithConfidence::new(
438 Latitude(415_520_000),
439 Longitude(21_340_000),
440 PositionConfidenceEllipse::new(
441 SemiAxisLength(4095),
442 SemiAxisLength(4095),
443 Wgs84AngleValue(3601),
444 ),
445 Altitude::new(AltitudeValue(12000), AltitudeConfidence::unavailable),
446 ),
447 ),
448 HighFrequencyContainer::basicVehicleContainerHighFrequency(hf),
449 None,
450 None,
451 None,
452 ),
453 ),
454 )
455}More examples
examples/bench_cam_tx.rs (line 150)
148fn make_cam(station_id: u32) -> Cam {
149 let hf = BasicVehicleContainerHighFrequency::new(
150 Heading::new(HeadingValue(900), HeadingConfidence(127)),
151 Speed::new(SpeedValue(0), SpeedConfidence(127)),
152 DriveDirection::unavailable,
153 VehicleLength::new(
154 VehicleLengthValue(1023),
155 VehicleLengthConfidenceIndication::unavailable,
156 ),
157 VehicleWidth(62),
158 AccelerationComponent::new(AccelerationValue(161), AccelerationConfidence(102)),
159 Curvature::new(CurvatureValue(1023), CurvatureConfidence::unavailable),
160 CurvatureCalculationMode::unavailable,
161 YawRate::new(YawRateValue(32767), YawRateConfidence::unavailable),
162 None,
163 None,
164 None,
165 None,
166 None,
167 None,
168 None,
169 );
170 Cam::new(
171 cam_header(station_id),
172 CamPayload::new(
173 generation_delta_time_now(),
174 CamParameters::new(
175 BasicContainer::new(
176 TrafficParticipantType(5),
177 ReferencePositionWithConfidence::new(
178 Latitude(415_520_000),
179 Longitude(21_340_000),
180 PositionConfidenceEllipse::new(
181 SemiAxisLength(4095),
182 SemiAxisLength(4095),
183 Wgs84AngleValue(3601),
184 ),
185 Altitude::new(AltitudeValue(12000), AltitudeConfidence::unavailable),
186 ),
187 ),
188 HighFrequencyContainer::basicVehicleContainerHighFrequency(hf),
189 None,
190 None,
191 None,
192 ),
193 ),
194 )
195}Trait Implementations
Sourceimpl AsnType for Heading
impl AsnType for Heading
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourceconst CONSTRAINTS: Constraints = Constraints::NONE
const CONSTRAINTS: Constraints = Constraints::NONE
The set of constraints for values of the given type.
Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Constructed<2> for Heading
impl Constructed<2> for Heading
Sourceimpl Decode for Heading
impl Decode for Heading
Sourcefn decode_with_tag_and_constraints<D: Decoder>(
decoder: &mut D,
tag: Tag,
constraints: Constraints,
) -> Result<Self, D::Error>
fn decode_with_tag_and_constraints<D: Decoder>( decoder: &mut D, tag: Tag, constraints: Constraints, ) -> Result<Self, D::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl Encode for Heading
impl Encode for Heading
Sourcefn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>(
&self,
encoder: &mut EN,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), EN::Error>
fn encode_with_tag_and_constraints<'encoder, EN: Encoder<'encoder>>( &self, encoder: &mut EN, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), EN::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreimpl Eq for Heading
impl StructuralPartialEq for Heading